@@ -64,5 +64,5 @@ class FeiShuPlugin(NotificationPlugin):
         requests.post(
             url=send_url,
             headers={"Content-Type": "application/json"},
-            data=json.dumps(data).encode("utf-8")
+            json=data
         )
